pitchtools.IntervalObject
=========================

.. abjad-lineage:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject

.. autoclass:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.cents
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.interval_class
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.number
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.semitones
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__abs__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__float__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__int__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalObject.IntervalObject.IntervalObject.__str__
   :noindex:
